Crate ezexec[−][src]
ezexec
Welcome to ezexec 🎉
ezexec provides a simple API to execute binaries or shell commands. Furthermore it implements a trivial but usually
good-enough API to find a binary in PATH or to get the current shell.
Example
// Lists all files in the current directory and forwards the output to the parent's stdout
ExecBuilder::with_shell("ls")?
.spawn_transparent()?
.wait()?;Modules
Implements the crate’s error types
Provides functions to get a binary or shell by it’s name
Macros
Creates a new variant
Creates a new ErrorImpl::ChildError kind
Creates a new ErrorImpl::ExecError kind
Creates a new ErrorImpl::PathError kind
Structs
A process executor
A child executor builder
A process executor